package com.game.business.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.game.common.core.domain.R;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.game.common.annotation.Log;
import com.game.common.core.controller.BaseController;
import com.game.common.core.domain.AjaxResult;
import com.game.common.enums.BusinessType;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import com.game.business.domain.AppGameItem;
import com.game.business.service.IAppGameItemService;
import com.game.common.utils.poi.ExcelUtil;
import com.game.common.core.page.TableDataInfo;

/**
 * 游戏选项Controller
 * 
 * @author game
 * @date 2024-06-29
 */
@RestController
@RequestMapping("/business/game_item")
@Api(value = "AppGameItemController", description = "游戏选项接口", tags = {"游戏选项"})
public class AppGameItemController extends BaseController
{
    @Autowired
    private IAppGameItemService appGameItemService;

    /**
     * 查询游戏选项列表
     */
    @PreAuthorize("@ss.hasPermi('business:game_item:list')")
    @GetMapping("/list")
    @ApiOperation(value = "查询游戏选项列表", notes = "获取游戏选项列表")
    public TableDataInfo<AppGameItem> list(AppGameItem appGameItem)
    {
        startPage();
        List<AppGameItem> list = appGameItemService.selectAppGameItemList(appGameItem);
        return getDataTable(list);
    }

    /**
     * 导出游戏选项列表
     */
    @PreAuthorize("@ss.hasPermi('business:game_item:export')")
    @Log(title = "游戏选项", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ApiOperation(value = "导出游戏选项列表", notes = "导出游戏选项列表")
    public void export(HttpServletResponse response, AppGameItem appGameItem)
    {
        List<AppGameItem> list = appGameItemService.selectAppGameItemList(appGameItem);
        ExcelUtil<AppGameItem> util = new ExcelUtil<AppGameItem>(AppGameItem.class);
        util.exportExcel(response, list, "游戏选项数据");
    }

    /**
     * 获取游戏选项详细信息
     */
    @PreAuthorize("@ss.hasPermi('business:game_item:query')")
    @GetMapping(value = "/{id}")
    @ApiOperation(value = "获取游戏选项详细信息", notes = "获取游戏选项详细信息")
    public R<AppGameItem> getInfo(@PathVariable("id") Long id)
    {
        return R.ok(appGameItemService.selectAppGameItemById(id));
    }

    /**
     * 新增游戏选项
     */
    @PreAuthorize("@ss.hasPermi('business:game_item:add')")
    @Log(title = "游戏选项", businessType = BusinessType.INSERT)
    @ApiOperation(value = "新增游戏选项", notes = "新增游戏选项")
    @PostMapping
    public R add(@RequestBody AppGameItem appGameItem)
    {
        return R.ok(appGameItemService.insertAppGameItem(appGameItem));
    }

    /**
     * 修改游戏选项
     */
    @PreAuthorize("@ss.hasPermi('business:game_item:edit')")
    @Log(title = "游戏选项", businessType = BusinessType.UPDATE)
    @ApiOperation(value = "修改游戏选项", notes = "修改游戏选项")
    @PutMapping
    public R edit(@RequestBody AppGameItem appGameItem)
    {
        return R.ok(appGameItemService.updateAppGameItem(appGameItem));
    }

    /**
     * 删除游戏选项
     */
    @PreAuthorize("@ss.hasPermi('business:game_item:remove')")
    @Log(title = "游戏选项", businessType = BusinessType.DELETE)
    @ApiOperation(value = "删除游戏选项", notes = "删除游戏选项")
	@DeleteMapping("/{ids}")
    public R remove(@PathVariable Long[] ids)
    {
        return R.ok(appGameItemService.deleteAppGameItemByIds(ids));
    }
}
